pub enum FactoryExecuteMsg {
Deploy {
kind: VersionKind,
module_instantiate_info: ModuleInstantiateInfo,
},
Remove {
contract_name: String,
version: [u8; 2],
},
UpdateMetadata {
contract_name: String,
version: [u8; 2],
changelog_url: Option<String>,
schema: Option<String>,
},
Proxy {
msg: WasmMsg,
},
NominateOwner {
nominated_owner_addr: String,
},
AcceptNominateOwner {},
RemoveNominateOwner {},
}Variants
Deploy
Deploys contract and saves metadata of the contract to the factory
Remove
Removes contract metadata from the factory if contract is paused or it is library contract. Last version of the contract can’t get removed
UpdateMetadata
Update fields of the contract metadata
Proxy
Pass through execution for versioned contract calls
NominateOwner
Factory owner (DAO) may submit a new owner to transfer ownership
AcceptNominateOwner
The nominated address must accept a nomination to finalize transfer of ownership NOTE: This is the only method that can be called, that isn’t from current owner_addr
RemoveNominateOwner
Factory owner (DAO) may revoke any/all ownership nominations at any time.