pub enum FactoryQueryMsg {
Config {},
LatestContracts {},
LatestContract {
contract_name: String,
},
VersionsByContractName {
contract_name: String,
from_index: Option<u64>,
limit: Option<u64>,
},
ContractNames {
from_index: Option<u64>,
limit: Option<u64>,
},
AllEntries {
from_index: Option<u64>,
limit: Option<u64>,
},
}Variants
Config
Gets the factory’s config
LatestContracts
Gets latest contract names and metadatas of the contracts
LatestContract
Gets latest version metadata of the contract
VersionsByContractName
Gets metadatas of the contract
ContractNames
Gets list of the contract names
AllEntries
Gets all contract names and metadatas stored in factory.